/* $Id: music.c,v 1.1.1.1 2000/12/08 14:17:25 bergo Exp $ */

/* MIDI-based music routines */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <unistd.h>
#include <time.h>
#include <sys/types.h>
#include <sys/time.h>

#include "../config.h"

#ifdef HAVE_SYS_SOUNDCARD_H
#include <sys/soundcard.h>
#include "music.h"

int seqfd=-1;

int nsynths;

time_t boundary=0;

#define BUFFSIZE 4096
SEQ_DEFINEBUF(BUFFSIZE);

int devsequencer=0;

struct Note {
  int on;
  int note;
  int ch;
  int pgm;
  int beat;
  int vol;
};

int Tempo, Timerbase;

struct synth_info card_info;

void loadfm();

/* public API */

/* /dev/music only works after I send a midi file to
   it with playmidi. weird. OSS documention sucks. */
int music_open() {
  int tmp,i;

  devsequencer=0;
  if ((seqfd=open("/dev/sequencer", O_WRONLY, 0))==-1)
    return -1;
  else
    devsequencer=1;
  //music_time_init(512,60);
  
  ioctl(seqfd,SNDCTL_SEQ_NRSYNTHS,&nsynths);
  if (!nsynths) {
    close(seqfd);
    return -1;
  }
  
  if (ioctl(seqfd, SNDCTL_SYNTH_INFO, &card_info) == -1) {
    fprintf(stderr, "cannot get info on soundcard\n");
    close(seqfd);
    return -1;
  }

  if (card_info.synth_type == SYNTH_TYPE_FM)
    loadfm();
  
  return 0;
}

void music_close() {
  close(seqfd);
}

void music_time_init(int timebase,int tempo) {
  int tmp;

  Tempo=tempo;

  if (!devsequencer) {
    Timerbase=timebase;
    tmp = timebase;
    if (ioctl(seqfd, SNDCTL_TMR_TIMEBASE, &tmp)==-1)
      perror("SNDCTL_TMR_TIMEBASE");
    tmp = tempo;
    if (ioctl(seqfd, SNDCTL_TMR_TEMPO, &tmp)==-1)
      perror("SNDCTL_TMR_TEMPO"); 
  } else {
    if (ioctl(seqfd, SNDCTL_SEQ_CTRLRATE,&tmp)==-1)
      perror("SNDCTL_SEQ_CTRLRATE");
    Timerbase=tmp;
    SEQ_SET_TEMPO(tempo);
  }
}

void music_reset() {
  ioctl(seqfd, SNDCTL_SEQ_RESET, 0);
}

void music_start() {
  SEQ_START_TIMER();
}

void music_load_patch(int chn, int pgm) {
  if (!devsequencer)
    SEQ_LOAD_GMINSTR(chn,pgm);
}

void music_pgm_change(int device,int chn, int pgm) {
  SEQ_PGM_CHANGE(device, chn, pgm);
}

void music_note_on(int device,int chn, int note, int vol) {
  SEQ_START_NOTE(device,chn,note,vol);
}

void music_note_off(int device,int chn, int note, int vol) {
  SEQ_STOP_NOTE(device,chn,note,vol);
}

void music_wait(int beats) {
  SEQ_DELTA_TIME(beats);
}

void music_flush() {
  SEQ_DUMPBUF();
}

int note_cmp(const void *a,const void *b);

int note_cmp(const void *a,const void *b) {
  struct Note *sa,*sb;
  sa=(struct Note *)a;
  sb=(struct Note *)b;
  if (sa->beat<sb->beat) return -1;
  if (sa->beat>sb->beat) return 1;
  return 0;
}

int music_play_macro(char *v1,char *v2,char *v3) {
  struct Note Q[1000];
  int i;
  int octave;
  int volume;
  int pgm;
  int beat;
  int value[256];
  char *p,c,*ap;
  int n,d;
  int cpgm[3];
  int cbeat;
  int note,vol,ch;
  char v[3][256];
  int lastvoice=1;
  time_t now;

  memset(v[0],0,256);
  memset(v[1],0,256);
  memset(v[2],0,256);

  strncpy(v[0],v1,255);

  if (v2) {
    strncpy(v[1],v2,255);
    ++lastvoice;
  }
  if (v3) {
    strncpy(v[2],v3,255);
    ++lastvoice;
  }

  octave=4;
  n=0;

  value['C']=0;
  value['D']=2;
  value['E']=4;
  value['F']=5;
  value['G']=7;
  value['A']=9;
  value['B']=11;
  value['R']=1000;

  for(i=0;i<lastvoice;i++) {

    beat=0;
    pgm=1;
    volume=64;

    p=strtok(v[i],"/");

    while(p!=NULL) {
      switch(p[0]) {
      case 'I': pgm=atoi(&p[1]); break;
      case 'T': music_time_init(512,atoi(&p[1])); break;
      case 'O': octave=atoi(&p[1]); break;
      case 'V': volume=atoi(&p[1]); break;
      default:
	c=(char)toupper(p[0]);
	Q[n].on=1;
	Q[n].note=(octave-1)*12+value[c];
	Q[n].ch=i+1;
	Q[n].pgm=pgm;
	Q[n].beat=beat;
	Q[n].vol=volume;
	
	ap=&p[1];
	if ((p[1]=='#')||(p[1]=='+')) {
	  Q[n].note++;
	  ap=&p[2];
	}

	if ((p[1]=='b')||(p[1]=='-')) {
	  Q[n].note--;
	  ap=&p[2];
	}

	switch(ap[0]) {
	case 0:   d=4; --ap; break;
	case '1': d=(ap[1]?16:1); ++ap; break;
	case '2': d=2; break;
	case '3': d=32; break;
	case '4': d=4; break;
	case '8': d=8; break;
	case '.': d=4; --ap; break;
	default:
	  d=4;
	}
	++ap;

	if (ap[0]=='.')
	  d-=d>>2;

	beat+=(Timerbase*60)/(d*Tempo);
	++n;
	memcpy(&Q[n],&Q[n-1],sizeof(struct Note));
	Q[n].beat=beat;
	Q[n].on=0;
	++n;

	break;	
      }
      p=strtok(NULL,"/");
    } /* while p!=NULL */
  } /* for i */

  qsort(&Q[0],n,sizeof(struct Note),note_cmp);
  cpgm[0]=cpgm[1]=cpgm[2]=-15;

  music_start();

  cbeat=0;
  for(i=0;i<n;i++) {
    if (Q[i].beat > cbeat) {
      music_wait(Q[i].beat-cbeat);
      cbeat=Q[i].beat;
    }
    note=Q[i].note;
    vol=Q[i].vol;
    ch=Q[i].ch;

    if (note>900)
      continue; /* pause */

    if (Q[i].on)
      if (Q[i].pgm != cpgm[ch-1]) {
	music_load_patch(ch,Q[i].pgm);
	music_pgm_change(0,ch,Q[i].pgm);
	cpgm[ch-1]=Q[i].pgm;
      }

    if (Q[i].on)
      music_note_on(0,ch,note,vol);
    else
      music_note_off(0,ch,note,vol);
  }
  music_flush();

  now=time(NULL);
  if (now>boundary)
    boundary=now+(cbeat/Timerbase);
  else
    boundary+=(cbeat/Timerbase);

  return((100*cbeat)/Timerbase);
}

int music_rest() {
  time_t now;
  now=time(NULL);
  return( (now>boundary)?0:((int)(boundary-now)));
}

void music_sync() {
  ioctl(seqfd,SNDCTL_SEQ_SYNC,0);
}

/* inner */

void seqbuf_dump() {
  fd_set wfds;
  struct timeval tv;

  FD_ZERO(&wfds);
  FD_SET(seqfd, &wfds);
  
  tv.tv_sec = 0;
  tv.tv_usec = 1000;

  if (_seqbufptr)
    if (select(seqfd + 1, 0, &wfds, 0, &tv)) {
      if (write (seqfd, _seqbuf, _seqbufptr) == -1) { 
	perror("uh oh (music)");
	exit (-1);
      } 
      _seqbufptr = 0;
    }
}


/* ************************************************************* 

   NOW, WHY OSS WON'T LOAD PATCHES FOR ME ON STARTUP IT PISSES
   ME OFF, THIS CODE AND DATA TAKEN FROM playmidi

   http://playmidi.sourceforge.net
   ************************************************************* */

static unsigned char std_sb[6656]={
0x53,0x42,0x49,0x1a,0x41,0x63,0x6f,0x75,
0x47,0x72,0x61,0x6e,0x64,0x50,0x69,0x61,
0x6e,0x6f,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x34,0x3c,0x4a,
0x4c,0x00,0x00,0x00,0x01,0x10,0x1b,0x00,
0xc3,0x92,0x23,0x62,0x02,0x01,0x1e,0x00,
0x00,0x00,0x00,0x00,0x32,0x4f,0x50,0x1a,
0x42,0x72,0x69,0x67,0x68,0x74,0x41,0x63,
0x6f,0x75,0x47,0x72,0x61,0x6e,0x64,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x54,0x2c,0x4a,0x00,0x00,0x00,0x00,
0x03,0x01,0x7d,0x00,0xf3,0xf3,0xf5,0xf5,
0x00,0x04,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x45,0x6c,0x65,0x63,
0x47,0x72,0x61,0x6e,0x64,0x50,0x69,0x61,
0x6e,0x6f,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x4c,0x4a,
0x00,0x00,0x00,0x00,0x03,0x01,0x61,0x00,
0xfb,0xf5,0xf5,0xf5,0x04,0x04,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x48,0x6f,0x6e,0x6b,0x79,0x2d,0x74,0x6f,
0x6e,0x6b,0x50,0x69,0x61,0x6e,0x6f,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x30,0x40,0x4a,0x00,0x00,0x00,0x00,
0x03,0x01,0xd7,0x00,0xf3,0xf2,0xf5,0xf5,
0x04,0x04,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x53,0x42,0x49,0x1a,0x52,0x68,0x6f,0x64,
0x65,0x73,0x20,0x50,0x69,0x61,0x6e,0x6f,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x34,0x48,0x4a,
0x34,0x00,0x00,0x00,0x35,0x12,0xd4,0x00,
0x94,0x92,0x91,0x62,0x02,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x43,0x68,0x6f,0x72,0x75,0x73,0x65,0x64,
0x20,0x50,0x69,0x61,0x6e,0x6f,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x4c,0x34,0x4a,0x00,0x00,0x02,0x00,
0x11,0x10,0x00,0x00,0xe1,0x92,0x63,0x72,
0x02,0x00,0x17,0x00,0x00,0x00,0x00,0x00,
0x32,0x4f,0x50,0x1a,0x48,0x61,0x72,0x70,
0x73,0x69,0x63,0x68,0x6f,0x72,0x64,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x34,0x48,0x4a,
0x00,0x00,0x00,0x00,0x22,0x01,0x8a,0x00,
0xe3,0xf4,0x79,0xa8,0x05,0x04,0x14,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x43,0x6c,0x61,0x76,0x69,0x6e,0x65,0x74,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x30,0x44,0x4a,0x00,0x00,0x00,0x00,
0x22,0x01,0x9c,0x00,0xf4,0xf3,0x18,0x55,
0x05,0x05,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x53,0x42,0x49,0x1a,0x43,0x65,0x6c,0x65,
0x73,0x74,0x61,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x34,0x4a,
0x00,0x00,0x00,0x00,0x02,0x01,0x00,0x00,
0x93,0xb6,0x74,0x45,0x00,0x00,0x15,0x00,
0x00,0x00,0x00,0x00,0x32,0x4f,0x50,0x1a,
0x47,0x6c,0x6f,0x63,0x6b,0x65,0x6e,0x73,
0x70,0x69,0x65,0x6c,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3c,0x4c,0x46,0x00,0x00,0x00,0x00,
0x1b,0x17,0x5a,0x00,0xd6,0xf3,0x53,0x53,
0x00,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x4d,0x75,0x73,0x69,
0x63,0x20,0x62,0x6f,0x78,0x20,0x20,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x2c,0x4c,0x46,
0x00,0x00,0x00,0x00,0x1b,0x14,0x5a,0x00,
0xf6,0x63,0xf6,0x73,0x00,0x00,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x56,0x69,0x62,0x72,0x61,0x70,0x68,0x6f,
0x6e,0x65,0x20,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3c,0x54,0x4a,0x00,0x00,0x00,0x00,
0x8b,0x84,0x5a,0x00,0xd8,0xf4,0x16,0xe5,
0x00,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x4d,0x61,0x72,0x69,
0x6d,0x62,0x61,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x38,0x58,0x4a,
0x00,0x00,0x00,0x00,0x08,0x01,0xc0,0x00,
0xfd,0xf6,0x56,0x68,0x00,0x00,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x58,0x79,0x6c,0x6f,0x70,0x68,0x6f,0x6e,
0x65,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x30,0x58,0x4a,0x00,0x00,0x00,0x00,
0x08,0x03,0xc0,0x00,0xf9,0xf7,0x56,0x68,
0x00,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x53,0x42,0x49,0x1a,0x54,0x75,0x62,0x75,
0x6c,0x61,0x72,0x20,0x42,0x65,0x6c,0x6c,
0x73,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x38,0x44,0x4a,
0x00,0x00,0x00,0x00,0x35,0x11,0xcd,0x00,
0xf2,0xf2,0xf1,0xf2,0x00,0x00,0x14,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x44,0x75,0x6c,0x63,0x69,0x6d,0x65,0x72,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x34,0x00,0x1c,0x00,
0x18,0x02,0x9a,0x05,0xb3,0xf0,0x8a,0xd3,
0x01,0x01,0x1c,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x48,0x61,0x6d,0x6d,
0x6f,0x6e,0x64,0x20,0x4f,0x72,0x67,0x61,
0x6e,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x50,0x38,0x46,
0x00,0x00,0x00,0x00,0x24,0x61,0xd4,0x00,
0x81,0x61,0x06,0xa6,0x03,0x00,0x12,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x50,0x65,0x72,0x63,0x75,0x73,0x73,0x69,
0x76,0x65,0x20,0x4f,0x72,0x67,0x61,0x6e,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3c,0x54,0x4a,0x00,0x00,0x00,0x00,
0xa3,0x21,0x95,0x00,0x81,0xd1,0xf9,0x0d,
0x01,0x00,0x12,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x52,0x6f,0x63,0x6b,
0x20,0x4f,0x72,0x67,0x61,0x6e,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x4c,0x4c,0x46,
0x00,0x00,0x00,0x00,0x25,0x61,0xd2,0x00,
0x81,0xd1,0x06,0x35,0x00,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x32,0x4f,0x50,0x1a,
0x43,0x68,0x75,0x72,0x63,0x68,0x20,0x4f,
0x72,0x67,0x61,0x6e,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x50,0x2c,0x46,0x00,0x00,0x00,0x00,
0x27,0x21,0x23,0x00,0x74,0x60,0x11,0x05,
0x00,0x00,0x12,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x52,0x65,0x65,0x64,
0x20,0x4f,0x72,0x67,0x61,0x6e,0x20,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x3c,0x54,0x46,
0x00,0x00,0x00,0x00,0x22,0x21,0x24,0x00,
0x76,0x76,0x06,0x06,0x04,0x04,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x41,0x63,0x63,0x6f,0x72,0x64,0x69,0x6f,
0x6e,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x44,0x54,0x46,0x00,0x00,0x00,0x00,
0x22,0x21,0x1b,0x00,0x66,0x66,0x05,0x06,
0x00,0x04,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x53,0x42,0x49,0x1a,0x48,0x61,0x72,0x6d,
0x6f,0x6e,0x69,0x63,0x61,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x4c,0x4c,0x4c,
0x00,0x00,0x00,0x00,0x22,0xb2,0x15,0x00,
0x41,0x31,0x04,0x04,0x03,0x01,0x12,0x00,
0x00,0x00,0x00,0x00,0x32,0x4f,0x50,0x1a,
0x54,0x61,0x6e,0x67,0x6f,0x20,0x41,0x63,
0x63,0x6f,0x72,0x64,0x69,0x6f,0x6e,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x4c,0x4a,0x00,0x00,0x00,0x00,
0x21,0x21,0x1e,0x00,0x76,0x66,0x04,0x17,
0x04,0x05,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x53,0x42,0x49,0x1a,0x41,0x63,0x6f,0x75,
0x73,0x74,0x69,0x63,0x20,0x47,0x75,0x69,
0x74,0x61,0x72,0x31,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x34,0x58,0x4a,
0x00,0x00,0x00,0x00,0x01,0x11,0xc0,0x00,
0xb5,0xd2,0x52,0x72,0x01,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x41,0x63,0x6f,0x75,0x73,0x74,0x69,0x63,
0x20,0x47,0x75,0x69,0x74,0x61,0x72,0x32,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3c,0x50,0x46,0x00,0x00,0x00,0x00,
0x23,0x11,0x8a,0x00,0x85,0xd2,0x54,0x73,
0x01,0x00,0x18,0x00,0x00,0x00,0x00,0x00,
0x32,0x4f,0x50,0x1a,0x45,0x6c,0x65,0x63,
0x74,0x72,0x69,0x63,0x20,0x47,0x75,0x69,
0x74,0x61,0x72,0x31,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x3c,0x4c,0x4a,
0x00,0x00,0x00,0x00,0x04,0x01,0x12,0x00,
0xfd,0xf2,0x43,0xa6,0x00,0x00,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x45,0x6c,0x65,0x63,0x74,0x72,0x69,0x63,
0x20,0x47,0x75,0x69,0x74,0x61,0x72,0x32,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x48,0x38,0x4a,0x00,0x00,0x00,0x00,
0x23,0x01,0x00,0x00,0xfc,0xf4,0x67,0xc6,
0x03,0x02,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x45,0x6c,0x65,0x63,
0x74,0x72,0x69,0x63,0x20,0x47,0x75,0x69,
0x74,0x61,0x72,0x33,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x54,0x4a,
0x00,0x00,0x00,0x00,0x01,0x01,0x06,0x00,
0xf6,0xf6,0x27,0x25,0x04,0x01,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x4f,0x76,0x65,0x72,0x64,0x72,0x69,0x76,
0x65,0x20,0x47,0x75,0x69,0x74,0x61,0x72,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x44,0x40,0x4a,0x00,0x00,0x00,0x00,
0x21,0x21,0xc1,0x00,0xf2,0xf2,0x13,0x16,
0x00,0x04,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x44,0x69,0x73,0x74,
0x6f,0x72,0x74,0x6f,0x6e,0x20,0x47,0x75,
0x69,0x74,0x61,0x72,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x34,0x40,0x4a,
0x00,0x00,0x00,0x00,0x21,0x21,0xc1,0x00,
0xf2,0xf2,0x14,0x15,0x00,0x04,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x47,0x75,0x69,0x74,0x61,0x72,0x20,0x48,
0x61,0x72,0x6d,0x6f,0x6e,0x69,0x63,0x73,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x44,0x4a,0x00,0x00,0x00,0x00,
0x0b,0x01,0x40,0x00,0x65,0xf2,0x1a,0x3e,
0x00,0x03,0x1c,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x41,0x63,0x6f,0x75,
0x73,0x74,0x69,0x63,0x20,0x42,0x61,0x73,
0x73,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x3c,0x38,0x4a,
0x00,0x00,0x00,0x00,0x01,0x01,0x0f,0x00,
0xd8,0x82,0x96,0x66,0x00,0x00,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x45,0x6c,0x65,0x63,0x74,0x72,0x69,0x63,
0x20,0x42,0x61,0x73,0x73,0x20,0x31,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x34,0x50,0x4a,0x00,0x00,0x00,0x00,
0x01,0x01,0x0b,0x00,0xf2,0xf6,0x97,0xe6,
0x04,0x01,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x45,0x6c,0x65,0x63,
0x74,0x72,0x69,0x63,0x20,0x42,0x61,0x73,
0x73,0x20,0x32,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x3c,0x48,0x4a,
0x00,0x00,0x00,0x00,0x01,0x01,0x04,0x00,
0xf2,0xf6,0x95,0xe6,0x04,0x01,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x46,0x72,0x65,0x74,0x6c,0x65,0x73,0x73,
0x20,0x42,0x61,0x73,0x73,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x30,0x4c,0x4a,0x00,0x00,0x00,0x00,
0x01,0x01,0x48,0x01,0xc7,0x91,0x96,0xe6,
0x00,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x53,0x6c,0x61,0x70,
0x20,0x42,0x61,0x73,0x73,0x20,0x31,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x38,0x50,0x4a,
0x00,0x00,0x00,0x00,0x0b,0x01,0x00,0x00,
0xfa,0xf3,0x86,0xb6,0x06,0x01,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x53,0x6c,0x61,0x70,0x20,0x42,0x61,0x73,
0x73,0x20,0x32,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x38,0x54,0x46,0x00,0x00,0x00,0x00,
0x0b,0x01,0x00,0x00,0xfa,0xf3,0x87,0xb7,
0x02,0x01,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x53,0x79,0x6e,0x74,
0x68,0x20,0x42,0x61,0x73,0x73,0x20,0x31,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x48,0x20,0x4a,
0x00,0x00,0x00,0x00,0xc1,0x01,0x00,0x0c,
0xe5,0xf5,0x65,0x95,0x00,0x00,0x11,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x53,0x79,0x6e,0x74,0x68,0x20,0x42,0x61,
0x73,0x73,0x20,0x32,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0xc1,0x01,0x00,0x09,0xf2,0xf2,0x45,0x96,
0x00,0x00,0x11,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x56,0x69,0x6f,0x6c,
0x69,0x6e,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x4a,0x38,0x4a,
0x00,0x00,0x00,0x00,0x62,0x61,0xca,0x00,
0xb4,0x44,0x25,0x06,0x04,0x04,0x1e,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x56,0x69,0x6f,0x6c,0x61,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x4c,0x30,0x4a,0x00,0x00,0x00,0x00,
0x24,0x21,0xcb,0x00,0x88,0x66,0x24,0x15,
0x04,0x04,0x1e,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x43,0x65,0x6c,0x6c,
0x6f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x4c,0x2e,0x4a,
0x00,0x00,0x00,0x00,0x24,0x21,0xd3,0x00,
0x88,0x66,0x24,0x16,0x04,0x04,0x1e,0x00,
0x00,0x3f,0x3f,0x00,0x53,0x42,0x49,0x1a,
0x43,0x6f,0x6e,0x74,0x72,0x61,0x62,0x61,
0x73,0x73,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0x71,0x61,0x23,0x00,0x51,0x52,0x43,0x15,
0x00,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x54,0x72,0x65,0x6d,
0x75,0x6c,0x6f,0x20,0x53,0x74,0x72,0x69,
0x6e,0x67,0x73,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x50,0x28,0x4a,
0x00,0x00,0x29,0x00,0xa2,0xa1,0xcb,0x00,
0x84,0x51,0x13,0x55,0x00,0x02,0x1a,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x50,0x69,0x7a,0x7a,0x69,0x63,0x61,0x74,
0x6f,0x20,0x53,0x74,0x72,0x69,0x6e,0x67,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x50,0x30,0x4a,0x00,0x00,0x00,0x00,
0xf1,0xe2,0x00,0x80,0xf5,0xfd,0xa8,0xac,
0x00,0x00,0x17,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4f,0x72,0x63,0x68,
0x65,0x73,0x74,0x72,0x61,0x6c,0x20,0x48,
0x61,0x72,0x70,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x38,0x3c,0x4a,
0x00,0x00,0x00,0x00,0x22,0x02,0x01,0x00,
0xd4,0xc4,0x34,0x26,0x01,0x00,0x19,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x54,0x69,0x6d,0x70,0x61,0x6e,0x79,0x20,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x50,0x30,0x4a,0x00,0x00,0x80,0x00,
0x10,0x10,0x55,0x00,0x30,0xb0,0x09,0x04,
0x03,0x03,0x1a,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x53,0x74,0x72,0x69,
0x6e,0x67,0x20,0x45,0x6e,0x73,0x65,0x6d,
0x62,0x6c,0x65,0x31,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x2a,0x00,0x62,0xa2,0x8b,0x40,
0x71,0x43,0x33,0xe5,0x01,0x00,0x14,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x53,0x74,0x72,0x69,0x6e,0x67,0x20,0x45,
0x6e,0x73,0x65,0x6d,0x62,0x6c,0x65,0x32,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x29,0x00,
0x61,0x21,0x8b,0x40,0x71,0x43,0x33,0xe5,
0x01,0x00,0x14,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x53,0x79,0x6e,0x74,
0x68,0x20,0x53,0x74,0x72,0x69,0x6e,0x67,
0x73,0x20,0x31,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x2b,0x00,0x61,0x22,0x8b,0x40,
0x71,0x43,0x33,0xe5,0x01,0x00,0x16,0x00,
0x00,0x00,0x00,0x00,0x32,0x4f,0x50,0x1a,
0x53,0x79,0x6e,0x74,0x68,0x53,0x74,0x72,
0x69,0x6e,0x67,0x73,0x20,0x32,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0x01,0x21,0x13,0x00,0x51,0x44,0x15,0x04,
0x02,0x01,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x53,0x42,0x49,0x1a,0x43,0x68,0x6f,0x69,
0x72,0x20,0x41,0x61,0x68,0x73,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x50,0x2c,0x4a,
0x00,0x00,0x4e,0x00,0xf3,0xc1,0x95,0x00,
0x32,0x43,0x40,0x46,0x02,0x01,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x56,0x6f,0x69,0x63,0x65,0x20,0x4f,0x6f,
0x68,0x73,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x54,0x2c,0x4a,0x00,0x00,0x4a,0x00,
0xf3,0xc1,0x51,0x00,0xa2,0x62,0xa4,0x84,
0x00,0x01,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x53,0x79,0x6e,0x74,
0x68,0x20,0x56,0x6f,0x69,0x63,0x65,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x48,0x30,0x4a,
0x00,0x00,0x00,0x00,0xe0,0xe3,0x4d,0x08,
0x52,0x65,0x51,0x35,0x02,0x00,0x16,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4f,0x72,0x63,0x68,0x65,0x73,0x74,0x72,
0x61,0x20,0x48,0x69,0x74,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3c,0x50,0x4a,0x00,0x00,0x30,0x00,
0x20,0x00,0x07,0x00,0xf7,0x96,0xb5,0x46,
0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x54,0x72,0x75,0x6d,
0x70,0x65,0x74,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x48,0x2c,0x4a,
0x00,0x00,0x00,0x00,0x21,0xa1,0x1c,0x00,
0x53,0x52,0x14,0x35,0x00,0x00,0x1c,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x54,0x72,0x6f,0x6d,0x62,0x6f,0x6e,0x65,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x30,0x4a,0x00,0x00,0x00,0x00,
0x21,0xa2,0x1a,0x80,0x53,0x52,0x19,0x39,
0x00,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x54,0x75,0x62,0x61,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0x21,0x21,0x21,0x00,
0x63,0x85,0x8c,0x2c,0x00,0x00,0x1c,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4d,0x75,0x74,0x65,0x64,0x20,0x54,0x72,
0x75,0x6d,0x70,0x65,0x74,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x44,0x3c,0x4a,0x00,0x00,0x00,0x00,
0xe1,0xe3,0x98,0x00,0x71,0x81,0xa5,0x96,
0x01,0x00,0x1c,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x46,0x72,0x65,0x6e,
0x63,0x68,0x20,0x48,0x6f,0x72,0x6e,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x3c,0x3c,0x4a,
0x00,0x00,0x00,0x00,0x31,0x21,0x55,0x00,
0x53,0xaa,0x54,0x15,0x00,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x42,0x72,0x61,0x73,0x73,0x20,0x53,0x65,
0x63,0x74,0x69,0x6f,0x6e,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x58,0x28,0x4a,0x00,0x00,0x39,0x00,
0x21,0xa2,0x1b,0x80,0x53,0x52,0x15,0x36,
0x00,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,
0x32,0x4f,0x50,0x1a,0x53,0x79,0x6e,0x74,
0x68,0x20,0x42,0x72,0x61,0x73,0x73,0x20,
0x31,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x54,0x2c,0x4a,
0x00,0x00,0x00,0x00,0x21,0x21,0x20,0x08,
0x83,0x81,0x75,0x86,0x05,0x04,0x1e,0x00,
0x00,0x3f,0x3f,0x00,0x53,0x42,0x49,0x1a,
0x53,0x79,0x6e,0x74,0x68,0x20,0x42,0x72,
0x61,0x73,0x73,0x20,0x32,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x3a,0x00,
0x21,0x21,0x8e,0x80,0x9b,0x90,0x25,0x05,
0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,
0x32,0x4f,0x50,0x1a,0x53,0x6f,0x70,0x72,
0x61,0x6e,0x6f,0x20,0x53,0x61,0x78,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x4a,
0x00,0x00,0x00,0x00,0x01,0x02,0x15,0x00,
0x70,0x70,0xe5,0xe6,0x05,0x00,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x41,0x6c,0x74,0x6f,0x20,0x53,0x61,0x78,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3c,0x4c,0x4a,0x00,0x00,0x00,0x00,
0x01,0x01,0x14,0x00,0x80,0x70,0xe5,0xe6,
0x05,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x54,0x65,0x6e,0x6f,
0x72,0x20,0x53,0x61,0x78,0x20,0x20,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x4a,
0x00,0x00,0x00,0x00,0x01,0x01,0x12,0x00,
0x80,0x70,0xe5,0xe6,0x05,0x00,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x53,0x42,0x49,0x1a,
0x42,0x61,0x72,0x69,0x74,0x6f,0x6e,0x65,
0x20,0x53,0x61,0x78,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x48,0x30,0x4a,0x00,0x00,0x00,0x00,
0x01,0xa3,0x91,0x00,0x51,0x52,0x57,0x77,
0x01,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4f,0x62,0x6f,0x65,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x3c,0x40,0x4a,
0x00,0x00,0x00,0x00,0x71,0x64,0xc9,0x00,
0x6e,0x8b,0x13,0x07,0x00,0x01,0x12,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x45,0x6e,0x67,0x6c,0x69,0x73,0x68,0x20,
0x48,0x6f,0x72,0x6e,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x54,0x20,0x4a,0x00,0x00,0x00,0x00,
0xa1,0xa3,0x25,0x00,0x71,0x82,0xa5,0x97,
0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,
0x32,0x4f,0x50,0x1a,0x42,0x61,0x73,0x73,
0x6f,0x6f,0x6e,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x58,0x2c,0x4a,
0x00,0x00,0x00,0x00,0x01,0x24,0x13,0x00,
0xf0,0x80,0x22,0x07,0x00,0x00,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x43,0x6c,0x61,0x72,0x69,0x6e,0x65,0x74,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x48,0x40,0x4a,0x00,0x00,0x00,0x00,
0x32,0x31,0x1d,0x00,0xa2,0x51,0x14,0x24,
0x04,0x00,0x1a,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x50,0x69,0x63,0x63,
0x6f,0x6c,0x6f,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x3c,0x38,0x4a,
0x00,0x00,0x00,0x00,0x21,0xa1,0x20,0x00,
0x77,0x65,0x43,0x06,0x00,0x00,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x46,0x6c,0x75,0x74,0x65,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x50,0x34,0x4a,0x00,0x00,0x00,0x00,
0x01,0xa1,0xa4,0x00,0x6a,0x63,0x64,0x66,
0x02,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x53,0x42,0x49,0x1a,0x52,0x65,0x63,0x6f,
0x72,0x64,0x65,0x72,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0x22,0x21,0xac,0x00,
0x67,0x65,0x89,0x28,0x00,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x50,0x61,0x6e,0x20,0x46,0x6c,0x75,0x74,
0x65,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0xe3,0xa1,0xe9,0x00,0x6d,0x65,0x8d,0x29,
0x00,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x32,0x4f,0x50,0x1a,0x42,0x6f,0x74,0x74,
0x6c,0x65,0x20,0x42,0x6c,0x6f,0x77,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x4a,
0x00,0x00,0x4c,0x00,0x20,0x26,0x10,0x00,
0xd8,0x68,0x68,0x97,0x00,0x00,0x1e,0x00,
0x00,0x3f,0x3f,0x00,0x53,0x42,0x49,0x1a,
0x53,0x68,0x61,0x6b,0x75,0x68,0x61,0x63,
0x68,0x69,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0x22,0x21,0x6c,0x00,0x47,0x65,0x0f,0x2a,
0x00,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x57,0x68,0x69,0x73,
0x74,0x6c,0x65,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0xe1,0xe2,0xff,0x00,
0x70,0x62,0x0c,0xfb,0x00,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x32,0x4f,0x50,0x1a,
0x4f,0x63,0x61,0x72,0x69,0x6e,0x61,0x20,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x50,0x28,0x4a,0x00,0x00,0x00,0x00,
0x31,0x31,0x2b,0x00,0x57,0x68,0x46,0x06,
0x04,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x53,0x42,0x49,0x1a,0x4c,0x65,0x61,0x64,
0x20,0x31,0x20,0x73,0x71,0x75,0x61,0x72,
0x65,0x65,0x61,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x58,0x20,0x4a,
0x00,0x00,0x00,0x00,0x91,0x13,0x97,0x80,
0x2a,0x42,0x02,0xf3,0x00,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4c,0x65,0x61,0x64,0x20,0x32,0x20,0x73,
0x61,0x77,0x74,0x6f,0x6f,0x74,0x68,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x50,0x30,0x4a,0x00,0x00,0x00,0x00,
0x00,0xa2,0x91,0x00,0x51,0x52,0x53,0x76,
0x01,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4c,0x65,0x61,0x64,
0x20,0x33,0x20,0x63,0x61,0x6c,0x6c,0x69,
0x6f,0x70,0x65,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x4c,0x2c,0x4a,
0x00,0x00,0x00,0x00,0x23,0x21,0xd8,0x00,
0x50,0x72,0x00,0xf8,0x03,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x32,0x4f,0x50,0x1a,
0x4c,0x65,0x61,0x64,0x20,0x34,0x20,0x63,
0x68,0x69,0x66,0x66,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3c,0x44,0x4a,0x00,0x00,0x00,0x00,
0xd1,0xa0,0x00,0x00,0xb7,0x87,0x66,0x06,
0x02,0x02,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x53,0x42,0x49,0x1a,0x4c,0x65,0x61,0x64,
0x20,0x35,0x20,0x63,0x68,0x61,0x72,0x61,
0x6e,0x67,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x38,0x2c,0x4a,
0x00,0x00,0x00,0x00,0x00,0x15,0x4f,0x00,
0x71,0x52,0x53,0x74,0x00,0x00,0x16,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4c,0x65,0x61,0x64,0x20,0x36,0x20,0x76,
0x6f,0x69,0x63,0x65,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x4c,0x28,0x4a,0x00,0x00,0x00,0x00,
0xe0,0xe1,0xc5,0x00,0x52,0x65,0xa1,0x35,
0x00,0x00,0x16,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4c,0x65,0x61,0x64,
0x20,0x37,0x20,0x66,0x69,0x66,0x74,0x68,
0x73,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0xb0,0xb1,0x00,0x00,
0xd5,0x26,0x13,0x13,0x01,0x00,0x15,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4c,0x65,0x61,0x64,0x20,0x38,0x20,0x62,
0x72,0x61,0x73,0x73,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x50,0x28,0x4a,0x00,0x00,0x3b,0x00,
0x21,0xa1,0x1d,0x80,0x53,0x52,0x14,0x35,
0x00,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x50,0x61,0x64,0x20,
0x31,0x20,0x6e,0x65,0x77,0x20,0x61,0x67,
0x65,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0x21,0xa1,0x1b,0x08,
0x51,0x82,0x15,0x45,0x01,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x50,0x61,0x64,0x20,0x32,0x20,0x77,0x61,
0x72,0x6d,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x50,0x2c,0x4a,0x00,0x00,0x00,0x00,
0xe1,0xa1,0xa3,0x00,0x6e,0x65,0x8f,0x06,
0x01,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x32,0x4f,0x50,0x1a,0x50,0x61,0x64,0x20,
0x33,0x20,0x70,0x6f,0x6c,0x79,0x73,0x79,
0x6e,0x74,0x68,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x38,0x4a,
0x00,0x00,0x00,0x00,0x20,0x01,0x00,0x08,
0xc3,0xf0,0xf4,0xf5,0x02,0x00,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x53,0x42,0x49,0x1a,
0x50,0x61,0x64,0x20,0x34,0x20,0x63,0x68,
0x6f,0x69,0x72,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x50,0x20,0x4a,0x00,0x00,0x56,0x00,
0xf1,0xc2,0x51,0x00,0xa2,0x63,0x40,0x46,
0x00,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x50,0x61,0x64,0x20,
0x35,0x20,0x62,0x6f,0x77,0x65,0x64,0x70,
0x61,0x64,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0xe1,0xa2,0x4d,0x00,
0x71,0x43,0x33,0xe5,0x01,0x00,0x16,0x00,
0x00,0x00,0x00,0x00,0x32,0x4f,0x50,0x1a,
0x50,0x61,0x64,0x20,0x36,0x20,0x6d,0x65,
0x74,0x61,0x6c,0x6c,0x69,0x63,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0x21,0x21,0x40,0x00,0x63,0x30,0x83,0x15,
0x00,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x53,0x42,0x49,0x1a,0x50,0x61,0x64,0x20,
0x37,0x20,0x68,0x61,0x6c,0x6f,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x4a,
0x00,0x00,0x00,0x00,0x24,0x21,0x24,0x00,
0x67,0x65,0x8f,0x2a,0x02,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x50,0x61,0x64,0x20,0x38,0x20,0x73,0x77,
0x65,0x65,0x70,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0x24,0x21,0x15,0x00,0x27,0x65,0x88,0x26,
0x02,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x32,0x4f,0x50,0x1a,0x46,0x58,0x20,0x31,
0x20,0x72,0x61,0x69,0x6e,0x20,0x20,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x50,0x4a,
0x00,0x00,0x00,0x00,0x08,0x83,0xc0,0x00,
0xfb,0xf5,0x66,0x66,0x00,0x00,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x53,0x42,0x49,0x1a,
0x46,0x58,0x20,0x32,0x20,0x73,0x6f,0x75,
0x6e,0x64,0x74,0x72,0x61,0x63,0x6b,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0xf4,0xe1,0x54,0x00,0x25,0xf0,0xbd,0x47,
0x00,0x01,0x10,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x46,0x58,0x20,0x33,
0x20,0x63,0x72,0x79,0x73,0x74,0x61,0x6c,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x4a,
0x00,0x00,0x00,0x00,0xb4,0xa1,0x0a,0x00,
0x67,0x65,0x88,0x2a,0x02,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x46,0x58,0x20,0x34,0x20,0x61,0x74,0x6d,
0x6f,0x73,0x70,0x68,0x65,0x72,0x65,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0x23,0x21,0xdb,0x08,0x47,0x65,0x8f,0x2a,
0x02,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x46,0x58,0x20,0x35,
0x20,0x62,0x72,0x69,0x67,0x68,0x74,0x6e,
0x65,0x73,0x73,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0x24,0x21,0x22,0x08,
0x47,0x65,0x8f,0x2a,0x02,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x46,0x58,0x20,0x36,0x20,0x67,0x6f,0x62,
0x6c,0x69,0x6e,0x73,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0xe6,0x30,0x0b,0x0b,0x25,0xf0,0xb5,0x45,
0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x46,0x58,0x20,0x37,
0x20,0x65,0x63,0x68,0x6f,0x65,0x73,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0xe3,0x70,0x50,0x88,
0x25,0xf0,0xb0,0x45,0x00,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x46,0x58,0x20,0x38,0x20,0x73,0x63,0x69,
0x2d,0x66,0x69,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0xe6,0xe0,0x15,0x09,0x70,0x62,0x07,0xf7,
0x00,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x32,0x4f,0x50,0x1a,0x53,0x69,0x74,0x61,
0x72,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x4a,
0x00,0x00,0x00,0x00,0x25,0x01,0x12,0x00,
0xf7,0xf8,0x43,0x05,0x04,0x04,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x42,0x61,0x6e,0x6a,0x6f,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3c,0x34,0x4a,0x00,0x00,0x00,0x00,
0x01,0x00,0x00,0x15,0xf4,0xf8,0xa6,0x35,
0x04,0x00,0x15,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x53,0x68,0x61,0x6d,
0x69,0x73,0x65,0x6e,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x3c,0x40,0x4a,
0x00,0x00,0x69,0x00,0x04,0x07,0x09,0x00,
0xfa,0xf8,0xa6,0xfb,0x00,0x00,0x14,0x00,
0x00,0x3f,0x3f,0x00,0x53,0x42,0x49,0x1a,
0x4b,0x6f,0x74,0x6f,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x20,0x4a,0x00,0x00,0x00,0x00,
0x00,0x01,0x13,0x00,0xf2,0xf4,0x13,0xf5,
0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4b,0x61,0x6c,0x69,
0x6d,0x62,0x61,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x48,0x28,0x4a,
0x00,0x00,0x00,0x00,0x00,0x01,0x0f,0x00,
0xf2,0xf4,0x13,0xf5,0x00,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x32,0x4f,0x50,0x1a,
0x42,0x61,0x67,0x70,0x69,0x70,0x65,0x20,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x50,0x28,0x4a,0x00,0x00,0x00,0x00,
0x11,0x32,0x0c,0x00,0xd0,0x80,0xf2,0x05,
0x00,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x46,0x69,0x64,0x64,
0x6c,0x65,0x20,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0x10,0x21,0x43,0x40,
0x9b,0x69,0x30,0x0e,0x03,0x05,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x53,0x68,0x61,0x6e,0x61,0x69,0x20,0x20,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0x11,0x32,0x0c,0x00,0xd0,0x80,0xf3,0x05,
0x00,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x54,0x69,0x6e,0x6b,
0x6c,0x65,0x20,0x42,0x65,0x6c,0x6c,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x4c,0x4a,
0x00,0x00,0x00,0x00,0x16,0x17,0x4f,0x00,
0xf6,0xf3,0x53,0x53,0x00,0x00,0x10,0x00,
0x00,0x3f,0x3f,0x00,0x32,0x4f,0x50,0x1a,
0x41,0x67,0x6f,0x67,0x6f,0x20,0x42,0x65,
0x6c,0x6c,0x73,0x20,0x20,0x20,0x20,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x38,0x4c,0x4a,0x00,0x00,0x00,0x00,
0x17,0x12,0x00,0x00,0xfa,0xf5,0x57,0x58,
0x00,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x53,0x42,0x49,0x1a,0x53,0x74,0x65,0x65,
0x6c,0x20,0x44,0x72,0x75,0x6d,0x73,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x4a,
0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0x00,
0xa8,0xd6,0x4b,0x4a,0x00,0x01,0x18,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x57,0x6f,0x6f,0x64,0x62,0x6c,0x6f,0x63,
0x6b,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x4a,0x00,0x00,0x00,0x00,
0x32,0x10,0x4a,0x00,0xf8,0xf5,0xff,0x7f,
0x00,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x54,0x61,0x69,0x6b,
0x6f,0x20,0x44,0x72,0x75,0x6d,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x48,0x4a,
0x00,0x00,0x00,0x00,0x00,0x00,0x0d,0x00,
0xa8,0xd6,0x4c,0x4f,0x00,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x32,0x4f,0x50,0x1a,
0x4d,0x65,0x6c,0x6f,0x64,0x69,0x63,0x20,
0x54,0x6f,0x6d,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x4a,0x00,0x00,0x00,0x00,
0x12,0x30,0x01,0x00,0xfb,0xf3,0xa7,0x53,
0x00,0x00,0x10,0x00,0x00,0x3f,0x3f,0x00,
0x32,0x4f,0x50,0x1a,0x53,0x79,0x6e,0x74,
0x68,0x20,0x44,0x72,0x75,0x6d,0x20,0x20,
0x20,0x20,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x4a,
0x00,0x00,0x75,0x00,0x2b,0x0b,0x00,0x08,
0xff,0xf7,0x0e,0xfe,0x00,0x00,0x1e,0x00,
0x00,0x3f,0x3f,0x00,0x53,0x42,0x49,0x1a,
0x52,0x65,0x76,0x65,0x72,0x73,0x65,0x20,
0x43,0x79,0x6d,0x62,0x61,0x6c,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x4a,0x00,0x00,0x00,0x00,
0x01,0x10,0x07,0x08,0xf5,0x54,0xb5,0x2f,
0x00,0x00,0x16,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x47,0x75,0x69,0x74,
0x61,0x72,0x20,0x46,0x72,0x65,0x74,0x4e,
0x6f,0x69,0x73,0x65,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0x00,0x18,0x80,0x08,
0xb3,0xaf,0x3f,0xf0,0x00,0x00,0x1a,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x42,0x72,0x65,0x61,0x74,0x68,0x20,0x4e,
0x6f,0x69,0x73,0x65,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x00,
0x60,0xef,0x40,0x15,0xb1,0xb2,0x73,0x9b,
0x02,0x03,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x53,0x65,0x61,0x73,
0x68,0x6f,0x72,0x65,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0xaf,0xb0,0x40,0x0f,
0xa1,0x52,0x53,0x73,0x00,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x42,0x69,0x72,0x64,0x20,0x54,0x77,0x65,
0x65,0x74,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x00,0x3c,
0x00,0x07,0x2e,0x08,0xf0,0x5f,0xf0,0xf0,
0x00,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x54,0x65,0x6c,0x65,
0x70,0x68,0x6f,0x6e,0x65,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x4a,
0x00,0x00,0x00,0x00,0xe5,0x70,0x13,0x09,
0x70,0x62,0x0f,0xff,0x00,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x48,0x65,0x6c,0x69,0x63,0x6f,0x70,0x74,
0x65,0x72,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x60,0x20,0x4a,0x00,0x00,0x7a,0x00,
0x00,0x10,0x00,0x08,0x68,0xa5,0xcf,0x6b,
0x02,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x32,0x4f,0x50,0x1a,0x41,0x70,0x70,0x6c,
0x61,0x75,0x73,0x65,0x2f,0x4e,0x6f,0x69,
0x73,0x65,0x20,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x60,0x20,0x4a,
0x00,0x00,0x00,0x00,0x2b,0x27,0x00,0x08,
0x82,0x77,0x0a,0x0a,0x00,0x05,0x1e,0x00,
0x00,0x3f,0x3f,0x00,0x53,0x42,0x49,0x1a,
0x47,0x75,0x6e,0x73,0x68,0x6f,0x74,0x20,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x4a,0x00,0x00,0x00,0x00,
0x00,0x00,0x0b,0x08,0xfa,0xf6,0x6f,0x8f,
0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,
};

static unsigned char drums_sb[6656]={
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x41,0x63,0x20,0x42,0x61,0x73,0x73,0x20,
0x44,0x72,0x75,0x6d,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x05,0x00,0x29,
0x42,0x01,0x1b,0x00,0x68,0xd6,0x1c,0x45,
0x03,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x42,0x61,0x73,0x73,
0x20,0x44,0x72,0x75,0x6d,0x20,0x31,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x06,0x00,0x2a,0x40,0x01,0x18,0x00,
0x68,0xd6,0x19,0x46,0x02,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x53,0x69,0x64,0x65,0x20,0x53,0x74,0x69,
0x63,0x6b,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x34,0x48,0x40,0x00,0x02,0x00,0x3c,
0x02,0x04,0x07,0x00,0xfa,0xda,0xbb,0xbe,
0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x41,0x63,0x6f,0x75,
0x73,0x74,0x69,0x63,0x20,0x53,0x6e,0x61,
0x72,0x65,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x40,
0x00,0x01,0x83,0x3b,0x17,0x00,0x00,0x00,
0xf3,0xf8,0xf0,0xb7,0x02,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x48,0x61,0x6e,0x64,0x20,0x43,0x6c,0x61,
0x70,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x34,0x48,0x38,0x00,0x02,0x00,0x41,
0x01,0x05,0x07,0x00,0x9a,0x9a,0xb6,0xb9,
0x02,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x45,0x6c,0x65,0x63,
0x74,0x72,0x69,0x63,0x20,0x53,0x6e,0x61,
0x72,0x65,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x34,0x4c,0x40,
0x00,0x01,0x83,0x3c,0x17,0x03,0x00,0x00,
0xf1,0xf7,0xf0,0xb7,0x02,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4c,0x6f,0x77,0x20,0x46,0x6c,0x6f,0x6f,
0x72,0x20,0x54,0x6f,0x6d,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x03,0x00,0x29,
0x01,0x01,0x0d,0x00,0xe8,0xa5,0xec,0xf7,
0x00,0x00,0x16,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x43,0x6c,0x6f,0x73,
0x65,0x64,0x20,0x48,0x69,0x67,0x68,0x20,
0x48,0x61,0x74,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x40,0x3f,
0x00,0x04,0x00,0x4f,0x2f,0x31,0x07,0x00,
0x73,0xc4,0xc2,0xb4,0x00,0x00,0x1a,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x48,0x69,0x67,0x68,0x20,0x46,0x6c,0x6f,
0x6f,0x72,0x20,0x54,0x6f,0x6d,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x02,0x00,0x30,
0x01,0x01,0x0d,0x00,0xe8,0xa5,0xec,0xf7,
0x01,0x00,0x16,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x50,0x65,0x64,0x61,
0x6c,0x20,0x48,0x69,0x67,0x68,0x20,0x48,
0x61,0x74,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x02,0xaf,0x4e,0x13,0x10,0xcd,0x80,
0xf5,0xd5,0x92,0xd4,0x01,0x00,0x1a,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4c,0x6f,0x77,0x20,0x54,0x6f,0x6d,0x20,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x02,0x00,0x29,
0x01,0x01,0x0d,0x00,0xe8,0xa5,0xec,0xf5,
0x00,0x00,0x16,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4f,0x70,0x65,0x6e,
0x20,0x48,0x69,0x67,0x68,0x20,0x48,0x61,
0x74,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x02,0xb4,0x41,0x3c,0x31,0x0a,0x40,
0x73,0xc4,0xb1,0xf3,0x00,0x00,0x1a,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4c,0x6f,0x77,0x2d,0x4d,0x69,0x64,0x20,
0x54,0x6f,0x6d,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x02,0x00,0x2c,
0x01,0x01,0x0d,0x00,0xe8,0xa5,0xec,0xf5,
0x00,0x00,0x16,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x48,0x69,0x67,0x68,
0x2d,0x4d,0x69,0x64,0x20,0x54,0x6f,0x6d,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x4c,0x40,
0x00,0x02,0x00,0x30,0x01,0x01,0x0d,0x00,
0xe8,0xa5,0xec,0xf5,0x00,0x00,0x16,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x43,0x72,0x61,0x73,0x68,0x20,0x43,0x79,
0x6d,0x62,0x61,0x6c,0x20,0x31,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x43,0x00,0x01,0x00,0x3c,
0x09,0x02,0x00,0x40,0xf1,0xf4,0x31,0x43,
0x02,0x00,0x18,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x48,0x69,0x67,0x68,
0x20,0x54,0x6f,0x6d,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x4c,0x40,
0x00,0x02,0x00,0x32,0x01,0x01,0x0d,0x00,
0xe8,0xa5,0xec,0xf5,0x00,0x00,0x16,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x52,0x69,0x64,0x65,0x20,0x43,0x79,0x6d,
0x62,0x61,0x6c,0x20,0x31,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x34,0x4c,0x40,0x00,0x02,0x00,0x3c,
0x3f,0x31,0x0a,0x00,0x73,0xc4,0xb2,0xf4,
0x00,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x43,0x68,0x69,0x6e,
0x65,0x73,0x65,0x20,0x43,0x79,0x6d,0x62,
0x61,0x6c,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x02,0x00,0x40,0x3c,0x11,0x05,0x00,
0x73,0x62,0xb2,0x93,0x00,0x00,0x1a,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x52,0x69,0x64,0x65,0x20,0x42,0x65,0x6c,
0x6c,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x01,0x00,0x3c,
0x18,0x13,0x4f,0x00,0xf2,0xf2,0x61,0x74,
0x00,0x00,0x18,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x54,0x61,0x6d,0x62,
0x6f,0x75,0x72,0x69,0x6e,0x65,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x40,
0x00,0x02,0xbd,0x3e,0xb2,0x31,0x00,0x00,
0x60,0x75,0xd2,0xd5,0x00,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x53,0x70,0x6c,0x61,0x73,0x68,0x20,0x43,
0x79,0x6d,0x62,0x61,0x6c,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x04,0x00,0x4f,
0x2a,0x11,0x0a,0x00,0x73,0x62,0xb1,0x92,
0x03,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x43,0x6f,0x77,0x20,
0x42,0x65,0x6c,0x6c,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x34,0x48,0x40,
0x00,0x01,0x00,0x3c,0xf7,0xc1,0x10,0x00,
0xff,0xf3,0x25,0x05,0x01,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x43,0x72,0x61,0x73,0x68,0x20,0x43,0x79,
0x6d,0x62,0x61,0x6c,0x20,0x32,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x02,0x00,0x3c,
0x1f,0x31,0x07,0x00,0x71,0x62,0xb1,0x93,
0x00,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x56,0x69,0x62,0x72,
0x61,0x73,0x6c,0x61,0x70,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x03,0x00,0x3a,0xe0,0xe1,0x0d,0x00,
0xe8,0xa5,0x54,0x95,0x00,0x00,0x16,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x52,0x69,0x64,0x65,0x20,0x43,0x79,0x6d,
0x62,0x61,0x6c,0x20,0x32,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x03,0x00,0x40,
0x3c,0x31,0x09,0x00,0x73,0xc4,0xb1,0xf4,
0x00,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x48,0x69,0x67,0x68,
0x20,0x42,0x6f,0x6e,0x67,0x6f,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x04,0x00,0x32,0x01,0x01,0x0b,0x00,
0xfa,0xf6,0x6c,0x86,0x00,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4c,0x6f,0x77,0x20,0x42,0x6f,0x6e,0x67,
0x6f,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x01,0x00,0x2d,
0x01,0x01,0x0b,0x00,0xfa,0xf6,0x6c,0x85,
0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4d,0x75,0x74,0x65,
0x20,0x48,0x69,0x67,0x68,0x20,0x43,0x6f,
0x6e,0x67,0x61,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x34,0x40,0x40,
0x00,0x02,0x00,0x2c,0x01,0x00,0x0d,0x00,
0xa9,0xd6,0x45,0x45,0x00,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4f,0x70,0x65,0x6e,0x20,0x48,0x69,0x67,
0x68,0x20,0x43,0x6f,0x6e,0x67,0x61,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x34,0x4c,0x40,0x00,0x03,0x00,0x30,
0x01,0x01,0x0b,0x00,0xa9,0xd6,0x44,0x46,
0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4c,0x6f,0x77,0x20,
0x43,0x6f,0x6e,0x67,0x61,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x34,0x40,0x40,
0x00,0x03,0x00,0x29,0x01,0x01,0x0b,0x00,
0xa9,0xd6,0x44,0x45,0x00,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x48,0x69,0x67,0x68,0x20,0x54,0x69,0x6d,
0x62,0x61,0x6c,0x65,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x04,0x00,0x1a,
0x91,0x11,0x10,0x00,0x60,0x72,0xd2,0xd5,
0x02,0x00,0x1a,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4c,0x6f,0x77,0x20,
0x54,0x69,0x6d,0x62,0x61,0x6c,0x65,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x05,0x00,0x16,0x91,0x11,0x11,0x00,
0x60,0x72,0xd0,0xd6,0x02,0x00,0x1a,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x48,0x69,0x67,0x68,0x20,0x41,0x67,0x6f,
0x67,0x6f,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x30,0x48,0x40,0x00,0x02,0x00,0x33,
0x01,0x01,0x0b,0x00,0xfa,0xf6,0x6c,0x87,
0x03,0x00,0x18,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4c,0x6f,0x77,0x20,
0x41,0x67,0x6f,0x67,0x6f,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x34,0x40,0x40,
0x00,0x01,0x00,0x2e,0x01,0x01,0x0b,0x00,
0xfa,0xf6,0x6c,0x87,0x00,0x00,0x18,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x43,0x61,0x62,0x61,0x73,0x61,0x20,0x20,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x34,0x48,0x40,0x00,0x04,0x00,0x37,
0xb2,0x31,0x03,0x00,0x60,0x75,0xa2,0xd6,
0x00,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4d,0x61,0x72,0x61,
0x63,0x61,0x73,0x20,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x40,
0x00,0x01,0x00,0x55,0x44,0x11,0x84,0x00,
0xdd,0xf5,0x84,0x76,0x00,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x53,0x68,0x6f,0x72,0x74,0x20,0x57,0x68,
0x69,0x73,0x74,0x6c,0x65,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x07,0x00,0x47,
0x33,0x32,0x12,0x00,0x30,0x5f,0x04,0x05,
0x02,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4c,0x6f,0x6e,0x67,
0x20,0x57,0x68,0x69,0x73,0x74,0x6c,0x65,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x0c,0x00,0x47,0x24,0x22,0x08,0x00,
0x64,0x6f,0x56,0x06,0x01,0x00,0x18,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x53,0x68,0x6f,0x72,0x74,0x20,0x47,0x75,
0x69,0x72,0x6f,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x06,0x00,0x34,
0x27,0x22,0x00,0x00,0xa5,0x69,0xc5,0x07,
0x03,0x00,0x1c,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4c,0x6f,0x6e,0x67,
0x20,0x47,0x75,0x69,0x72,0x6f,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x0c,0x00,0x34,0x27,0x22,0x00,0x00,
0xa5,0x69,0xe5,0x07,0x03,0x00,0x1c,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x43,0x6c,0x61,0x76,0x65,0x73,0x20,0x20,
0x20,0x20,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x30,0x4c,0x40,0x00,0x02,0x00,0x45,
0x34,0x11,0x47,0x00,0xd8,0xf5,0xf0,0x76,
0x00,0x00,0x10,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x48,0x69,0x67,0x68,
0x20,0x57,0x6f,0x6f,0x64,0x20,0x42,0x6c,
0x6f,0x63,0x6b,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x30,0x48,0x40,
0x00,0x02,0x00,0x3f,0x33,0x11,0x48,0x00,
0xf9,0xf5,0xf6,0x75,0x00,0x00,0x1e,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4c,0x6f,0x77,0x20,0x57,0x6f,0x6f,0x64,
0x20,0x42,0x6c,0x6f,0x63,0x6b,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x30,0x48,0x40,0x00,0x02,0x00,0x3a,
0x33,0x11,0x47,0x00,0xf9,0xf5,0xf5,0x75,
0x00,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4d,0x75,0x74,0x65,
0x20,0x43,0x75,0x69,0x63,0x61,0x20,0x20,
0x20,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x01,0x00,0x3c,0x05,0x04,0xc0,0x00,
0xf1,0xfc,0xf0,0x16,0x02,0x01,0x1c,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4f,0x70,0x65,0x6e,0x20,0x43,0x75,0x69,
0x63,0x61,0x20,0x20,0x20,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x34,0x4c,0x40,0x00,0x01,0x00,0x3c,
0x09,0x06,0xcb,0x00,0xf1,0xfc,0xf0,0x04,
0x02,0x00,0x1e,0x00,0x00,0x00,0x00,0x00,
0x53,0x42,0x49,0x1a,0x4d,0x75,0x74,0x65,
0x20,0x54,0x72,0x69,0x61,0x6e,0x67,0x6c,
0x65,0x20,0x20,0x20,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x34,0x48,0x40,
0x00,0x01,0x00,0x3c,0x08,0x09,0xc0,0x00,
0xf1,0xfc,0xf0,0x16,0x01,0x00,0x10,0x00,
0x00,0x00,0x00,0x00,0x53,0x42,0x49,0x1a,
0x4f,0x70,0x65,0x6e,0x20,0x54,0x72,0x69,
0x61,0x6e,0x67,0x6c,0x65,0x20,0x20,0x20,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x30,0x48,0x40,0x00,0x01,0x00,0x3c,
0x0c,0x07,0xcf,0x00,0xf1,0xfc,0xf0,0x04,
0x02,0x00,0x10,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x40,0x40,0x40,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
};

/************************************************************************
   patchload.c  --  loads patches for playmidi package
   Some of this code was adapted from code written by Hannu Solovainen

   Copyright (C) 1994-1996 Nathan I. Laredo

   2000/11/30   --  Modified by Felipe Bergo to read patches from a
                    static array instead of reading from files.

   This program is modifiable/redistributable under the terms
   of the GNU General Public Licence.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
   Send your comments and all your spare pocket change to
   laredo@gnu.ai.mit.edu (Nathan Laredo) or to PSC 1, BOX 709, 2401
   Kelly Drive, Lackland AFB, TX 78236-5128, USA.
 *************************************************************************/

int reverb=1;

void adjustfm(buf, key)
char *buf;
int key;
{
    unsigned char pan = 2 << 4;

    if (key == FM_PATCH) {
	buf[39] &= 0xc0;
	if (buf[46] & 1)
	    buf[38] &= 0xc0;
	buf[46] = (buf[46] & 0xcf) | pan;
	if (reverb) {
	    unsigned val;
	    val = buf[43] & 0x0f;
	    if (val > 0)
		val--;
	    buf[43] = (buf[43] & 0xf0) | val;
	}
    } else {
	int mode;
	if (buf[46] & 1)
	    mode = 2;
	else
	    mode = 0;
	if (buf[57] & 1)
	    mode++;
	buf[50] &= 0xc0;
	if (mode == 3)
	    buf[49] &= 0xc0;
	if (mode == 1)
	    buf[39] &= 0xc0;
	if (mode == 2 || mode == 3)
	    buf[38] &= 0xc0;
	buf[46] = (buf[46] & 0xcf) | pan;
	buf[57] = (buf[57] & 0xcf) | pan;
	if (mode == 1 && reverb) {
	    unsigned val;
	    val = buf[43] & 0x0f;
	    if (val > 0)
		val--;
	    buf[43] = (buf[43] & 0xf0) | val;
	    val = buf[54] & 0x0f;
	    if (val > 0)
		val--;
	    buf[54] = (buf[54] & 0xf0) | val;
	}
    }
}

void loadfm()
{
  int wantopl3=0;
  int i, n, voice_size, data_size;
  char buf[60];
  struct sbi_instrument instr;
  
  srand(getpid());
  voice_size = 52;
  instr.device = 0;
  
  for (i = 0; i < 128; i++) {
    instr.channel = i;

    memset(buf,0,60);
    memcpy(buf,&std_sb[voice_size*i],voice_size);
    
    if (strncmp(buf, "4OP", 3) == 0) {
      instr.key = OPL3_PATCH;
      data_size = 22;
    } else {
      instr.key = FM_PATCH;
      data_size = 11;
    }
    
    adjustfm(buf, instr.key);
    for (n = 0; n < 32; n++)
      instr.operators[n] = (n < data_size) ? buf[36 + n] : 0;
    
    SEQ_WRPATCH(&instr, sizeof(instr));
  }
  
  for (i = 128; i < 175; i++) {
    memset(buf,0,60);
    memcpy(buf,&drums_sb[voice_size*i],voice_size);
    instr.channel = i;
    
    if (strncmp(buf, "4OP", 3) == 0) {
      instr.key = OPL3_PATCH;
      data_size = 22;
    } else {
      instr.key = FM_PATCH;
      data_size = 11;
    }
    adjustfm(buf, instr.key);
    for (n = 0; n < 32; n++)
      instr.operators[n] = (n < data_size) ? buf[n + 36] : 0;
    
    SEQ_WRPATCH(&instr, sizeof(instr));
  }
}
#endif
